from DrissionPage import ChromiumPage
from DataRecorder import Recorder
from DrissionPage._configs.chromium_options import ChromiumOptions

path = r'C:\Program Files (x86)\ChatAI Chrome\ChatAI_Chrome.exe'  # 请改为你电脑内Chrome可执行文件路径
ChromiumOptions().set_browser_path(path).save()



# 创建页面对象
page = ChromiumPage()

# 访问网页
page.get('https://www.maoyan.com/board/4')

while True:
    # 遍历页面上所有 dd 元素
    for mov in page.eles('t:dd'):
        # 获取需要的信息
        num = mov('t:i').text
        score = mov('.score').text
        title = mov('@data-act=boarditem-click').attr('title')
        star = mov('.star').text
        time = mov('.releasetime').text
        # 写入到记录器
         # recorder.add_data((num, title, star, time, score))
        print(num, score, title, star, time)

    # 获取下一页按钮，有就点击
    btn = page('下一页', timeout=10)
    if btn:
        btn.click()
        page.wait.load_start()
    # 没有则退出程序
    else:
        break







from flask import Flask, render_template
import logset
import time
from recordJob import jobStart
import controller  # 导入 controller.py 文件
app = Flask(__name__)




# 设置日志
logger = logset.setup_logging()


# 初始化路由
controller.init_routes(app)
# 启动定时任务
jobStart()


if __name__ == '__main__':
    logger.info("Starting   App")
    app.run(host='127.0.0.1', port=5000)










from flask import render_template
from status import get_config_params, get_job_status
import logset
# 设置日志
logger = logset.setup_logging()
def init_routes(app):


    @app.route('/')
    def index():
        logger.info("Index page accessed")
        return "Flask App is running with job running in the background."

    @app.route('/status')
    def status():
        logger.info("Status page accessed")
        config_params = get_config_params()
        job_status = get_job_status()
        return render_template('status.html', config_params=config_params, job_status=job_status)




from setuptools import setup, find_packages

setup(
    name='automock25',  # 包的名称
    version='0.1.3',           # 包的版本号
    packages=find_packages(),  # 自动查找所有包和子包
    # install_requires=[        # 项目依赖的其他包
    #     'numpy>=1.18.5',
    #     'requests>=2.24.0',
    # ],
    author='peak',        # 作者名称
    author_email='your.email@example.com',  # 作者邮箱
    description='自动模拟充值',  # 简短描述
    # long_description=open('README.md').read(),  # 详细描述，通常从 README 文件读取
    long_description_content_type='text/markdown',  # 描述内容的格式
    #url='https://github.com/yourusername/your_package_name',  # 项目主页或仓库地址
    classifiers=[  # 分类器，用于描述项目的特性
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',

    ],
    python_requires='>=3.6',  # 支持
    #include_package_data=True,  # 包含包数据（如静态文件）
    #  entry_points={  # 可选，用于创建命令行工具
    #     'console_scripts': [
    #         'your_command=your_package.module:main_function',
    #     ],
    # },
    # include_package_data=True,  # 包含包数据（如静态文件）
    # package_data={  # 可选，指定包含的数据文件
    #     'your_package': ['data/*.dat'],
    # },
    # exclude_package_data={  # 可选，指定排除的数据文件
    #     'your_package': ['data/exclude_this.dat'],
    # },
    # zip_safe=False,  # 可选，指定是否可以安全地以 zip 形式安装
)



from DrissionPage._configs.chromium_options import ChromiumOptions
from DrissionPage import WebPage
import time
from datetime import datetime
import logset
import record
# 获取日志记录器
logger = logset.setup_logging()


def charge(order_data):
    # 这里可以添加处理订单的逻辑
    current_time = datetime.now()
    formatted_time = current_time.strftime('%Y-%m-%d %H:%M:%S')
    order_data['chargetime'] =  formatted_time
    logger.info(f"Charging order: {order_data}")
    page = WebPage()
    page.get('https://shop.10086.cn/mall_210_210.html')

    elephone = page.ele('@name=phonenum')
    #print(elephone.text())
    if elephone:
        elephone.input(order_data['resdata']['mobile'])  # 原写法
        # elephone.set.attr('value', order_data['resdata']['mobile'])
    else:
        logger.info("手机号码框没找到.")
        return


    # 等待元素加载
    time.sleep(1)  # 等待2秒
    # 点击 元
    page.ele('tag:span@class=yuan_show toggle').click()
    # 等待页面加载
    #page.wait.load_start()


    #classamount ='home_firstscreen_'+str(order_data['resdata']['amount'])
    stramount = str(order_data['resdata']['amount'])+' 元'
    logger.info(stramount)

    elesa=page('tag:dd@class=yuan')
    elesa_arr=elesa.eles('tag:a')
    amountFlag = 0
    for c in elesa_arr:
        if c.text == stramount:
            c.click()  # 点击元素
            print(c.text + " --面值 clicked successfully.")
            amountFlag=1
            break
        else:
            logger.info("面值 not found."+c.text)
    #    print(c.text)
    if amountFlag==1:
        btnCharge=page('tag:a@url=https://shop.10086.cn/i/?f=rechargecredit')
        if btnCharge:
            btnCharge.click()
        else:
            logger.info("立即交费的按钮没找到.")
            return


    #amounttaga=elesa_c.ele('text:{stramount}')
    #print(amounttaga.text())
    order_data['status'] = '2'
    order_data['statusname'] = '充值成功'
    f_current_time = datetime.now()
    finishtime = current_time.strftime('%Y-%m-%d %H:%M:%S')
    order_data['finishtime'] = finishtime
    record.push_order(order_data)

    # 示例：假设需要根据订单数据进行某些操作
    # 例如：扣款、记录日志等
    # 这里暂时只打印订单数据
    # 实际应用中可以添加具体的业务逻辑
    return {"status": "success", "message": "Order charged successfully"}




